#ifndef _CHRONOPTICS_TOF_USER_CONFIG_H_
#define _CHRONOPTICS_TOF_USER_CONFIG_H_

#include <chronoptics/tof/camera_config.h>
#include <chronoptics/tof/camera.h>
#include <chronoptics/tof/processing_config.h>

#ifdef __cplusplus
extern "C" {
#endif

/** Optimized configurations for different use cases
 */
enum tof_config_mode {
  TOF_CONFIG_MODE_LONG_RANGE_DYNAMIC_SCENE = 1, /** Suitable for most applications */
  TOF_CONFIG_MODE_MEDIUM_RANGE_DYNAMIC_SCENE = 2, /** For fast moving applications */
  TOF_CONFIG_MODE_MEDIUM_RANGE_BALANCED = 3, /** Balanced between range, speed and accuracy */
  TOF_CONFIG_MODE_SHORT_RANGE_HIGH_SPEED = 4, /** Maximum speed mode for short range and fast moving applications */
  TOF_CONFIG_MODE_LONG_RANGE_HIGH_RESOLUTION = 5, /** Full resolution long range */
  TOF_CONFIG_MODE_MEDIUM_RANGE_STATIC_SCENE = 6, /** Full resolution for slow changing scene */
  TOF_CONFIG_MODE_FAR_OUT_STATIC_SCENE = 7, /** Full resolution for slow changing scene */
};

/** Get the camera config associated with the config mode
 * @param camera Camera
 * @param config_mode Config mode
 * @param error Pointer to error
 * @return Camera Config
 */
TOF_EXPORT tof_camera_config_t tof_config_mode_camera_config(tof_camera_t camera, enum tof_config_mode config_mode, tof_error_t *error);

/** Get the processing config associated with the config mode
 * @param camera Camera
 * @param config_mode Config mode
 * @param error Pointer to error
 * @return Processing Config
 */
TOF_EXPORT tof_processing_config_t tof_config_mode_processing_config(tof_camera_t camera, enum tof_config_mode config_mode, tof_error_t *error);

/** Check whether hdr is possible with current camera config
 * @param config The camera config to check
 * @param error Pointer to error
 * @return Whether hdr is possible
 */
TOF_EXPORT bool tof_hdr_possible(tof_camera_config_ct config, tof_error_t *error);

/** Check whether phase unwrap is possible with current camera config
 * @param config The camera config to check
 * @param error Pointer to error
 * @return Whether phase unwrap is possible
 */
TOF_EXPORT bool tof_phase_unwrap_possible(tof_camera_config_ct config, tof_error_t *error);

/** Generate processing config based on camera configuration and calibration.
 * @param camera A camera
 * @param error Pointer to error
 */
TOF_EXPORT void tof_apply_default_processing_config(tof_camera_t camera, tof_error_t *error);

#ifdef __cplusplus
}
#endif

#endif
