classdef TuiCamera < tof.LiveCamera
  % TuiCamera
  %   The main interface to the tui camera
  %
  % Methods:
  %   setGpioMode - Set GPIO mode for a certain pin
  %   setTriggerMode - Set trigger mode
  %

  methods(Access=public)
    function obj = TuiCamera(varargin)
      % TuiCamera
      %   Construct new tui_camera class
      %
      % ----------
      %
      %   Construct the tui camera
      %
      % Inputs:
      %   1 - string - The serial number of the camera to connect to, if the
      %                camera is available over both usb and gige it will be
      %                connected over usb. If an empty string is supplied the
      %                camera will connect to the first usb camera, if no usb
      %                camera is connected it will connect to the first gige
      %                camera that replies (this reply time is random, so you
      %                might connect to a different camera each time if you've
      %                got multiple cameras connected to your network).
      %

      if nargin == 1 && isa(varargin{1}, 'uint64')
        ptr = varargin{1};
      elseif nargin == 1 && (isStringScalar(varargin{1}) || ischar(varargin{1}))
        ptr = tof.mex('tof_tui_camera_new', varargin{1});
      else
        error("Can't construct empty object");
      end

      obj@tof.LiveCamera(ptr);

    end

    function delete(~)
    end

    function ptr = get_object_ptr(obj)
      ptr = obj.mPtr;
    end

    function setGpioMode(obj, pin, gpio_mode)
      % setGpioMode
      %   Set GPIO mode for a certain pin
      %
      % Inputs:
      %   pin - numeric - Pin
      %   gpio_mode - GpioMode - GPIO Mode
      %

      tof.mex('tof_tui_camera_set_gpio_mode', obj.mPtr, pin, uint32(gpio_mode));
    end

    function setTriggerMode(obj, trigger_mode)
      % setTriggerMode
      %   Set trigger mode
      %
      % Inputs:
      %   trigger_mode - TriggerMode - Trigger mode
      %

      tof.mex('tof_tui_camera_set_trigger_mode', obj.mPtr, uint32(trigger_mode));
    end

  end
end
