#include <cassert>
#include <chronoptics/tof.hpp>
#include <chronoptics/tof/data_types.hpp>
#include <iostream>

namespace tof = chronoptics::tof;

int main() {
  tof::TuiCamera cam("3030003");
  cam.set_output_frame_types({tof::FrameType::XYZ_BGR, tof::FrameType::BGR});
  cam.start();

  // drop frames
  std::cout << "Dropping frames\n";
  for (size_t i = 0; i < 100; i++) {
    cam.get_frames();
  }
  std::cout << "Dropped frames\n";

  auto frames = cam.get_frames();

  auto &xyz = frames[0];
  auto &bgr = frames[1];

  auto cal = cam.get_calibration();

  int row = 140;
  int col = 280;

  auto val = xyz.at<tof::XYZBGR>(row * xyz.cols() + col);

  if (val.z == 0) {
    std::cout << "Depth value is zero, choose different row/col location\n";
    return -1;
  }

  auto depth_pos = tof::transform_3d_to_depth_2d(val.x, val.y, val.z, cal);

  assert(depth_pos.row() == row);
  assert(depth_pos.col() == col);

  auto rgb_pos = tof::transform_3d_to_color_2d(val.x, val.y, val.z, cal);

  auto rgb_val = bgr.at<tof::BGR>(rgb_pos.row() * bgr.cols() + rgb_pos.col());

  assert(rgb_val.r == val.r);
  assert(rgb_val.g == val.g);
  assert(rgb_val.b == val.b);

  // "Use" rgb_val such that -Wunused-variable isn't triggered on release builds
  (void)rgb_val;

  depth_pos = tof::transform_color_2d_to_depth_2d(rgb_pos.row(), rgb_pos.col(),
                                                  xyz, cal);

  assert(depth_pos.row() == row);
  assert(depth_pos.col() == col);

  return 0;
}